BorderContainer Experiments | The Dojo Toolkit

# This is a test

This is only a test. An experiment in dynamically altering a BorderContainer's layout (a seemingly unsupported feature just yet). It Demonstrates how to programatically alter/animate the size of non-center regions though, and several simple layout configurations

### Layouts:

pane0
Sinlge pane - l1

### two panes, vertical split:

Sinlge pane - left
Sinlge pane - center
Single pane - center (splitter) (this is unsupported, and does not work)
Single pane - right (no splitter)
Single pane - center (no splitter)
Single pane - right (splitter)
Single pane - top (splitter)
Single pane - center
Single pane - center
Single Pane Bottom (splitter)
Single Pane Top (splitter)
pane 1
pane 2
pane 3